Installation
============

:py:mod:`uravu` can be installed from the PyPI package manager with :py:mod:`pip`

.. code-block:: bash 

   pip install uravu

Alternatively, if you would like to download and install the latest development build, it can be found `Github`_ along with specific installation instructions. 

.. _Github: https://github.com/arm61/uravu
